package com.jsowell.pile.service;

import java.util.List;

import com.jsowell.pile.domain.PileStationWhitelist;

/**
 * 站点白名单Service接口
 *
 * @author jsowell
 * @date 2023-04-19
 */
public interface IPileStationWhitelistService {
	/**
	 * 查询站点白名单
	 *
	 * @param id 站点白名单主键
	 * @return 站点白名单
	 */
	public PileStationWhitelist selectPileStationWhitelistById(Long id);

	/**
	 * 查询站点白名单列表
	 *
	 * @param pileStationWhitelist 站点白名单
	 * @return 站点白名单集合
	 */
	public List<PileStationWhitelist> selectPileStationWhitelistList(PileStationWhitelist pileStationWhitelist);

	/**
	 * 新增站点白名单
	 *
	 * @param pileStationWhitelist 站点白名单
	 * @return 结果
	 */
	public int insertPileStationWhitelist(PileStationWhitelist pileStationWhitelist);

	/**
	 * 修改站点白名单
	 *
	 * @param pileStationWhitelist 站点白名单
	 * @return 结果
	 */
	public int updatePileStationWhitelist(PileStationWhitelist pileStationWhitelist);

	/**
	 * 批量删除站点白名单
	 *
	 * @param ids 需要删除的站点白名单主键集合
	 * @return 结果
	 */
	public int deletePileStationWhitelistByIds(Long[] ids);

	/**
	 * 删除站点白名单信息
	 *
	 * @param id 站点白名单主键
	 * @return 结果
	 */
	public int deletePileStationWhitelistById(Long id);

	PileStationWhitelist queryWhitelistByMemberId(String stationId, String memberId);
}
